@@ -2,10 +2,8 @@
 
 #define REAL_PATH "/usr/share/backuppc/lib/realindex.cgi"
 
-int main(ac, av)
-char **av;
-{
-    execv(REAL_PATH, av);
+int main (int argc, char *argv[]) {
+    execv(REAL_PATH, argv);
     return 0;
 }
 
